"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.is = exports.cloneDeep = exports.merge = exports.isFile = exports.isArray = void 0;
const matcher_1 = require("./matcher");
function isArray(object) {
    return Object.prototype.toString.call(object) === '[object Array]';
}
exports.isArray = isArray;
function isFile(object) {
    return object instanceof File || object instanceof FileList;
}
exports.isFile = isFile;
function merge(a, b) {
    for (const key in b) {
        a[key] = cloneDeep(b[key]);
    }
}
exports.merge = merge;
function cloneDeep(object) {
    if (object === null) {
        return null;
    }
    if (isFile(object)) {
        return object;
    }
    if (isArray(object)) {
        const clone = [];
        for (const key in object) {
            if (object.hasOwnProperty(key)) {
                clone[key] = cloneDeep(object[key]);
            }
        }
        return clone;
    }
    if (typeof object === 'object') {
        const clone = {};
        for (const key in object) {
            if (object.hasOwnProperty(key)) {
                clone[key] = cloneDeep(object[key]);
            }
        }
        return clone;
    }
    return object;
}
exports.cloneDeep = cloneDeep;
function is(errors, error) {
    if (typeof error === 'string' && error.match(/[\*\!]/)) {
        return errors.filter((w) => matcher_1.isMatch(w, error)).length > 0;
    }
    return isArray(error)
        ? error.some((w) => is(errors, w))
        : errors.includes(error);
}
exports.is = is;
